@@ -9,7 +9,7 @@ import warnings
 import os
 import numpy as np
 import pandas as pd
-import gdal
+from osgeo import gdal
 import urllib
 from bs4 import BeautifulSoup
 import re
