@@ -8,7 +8,7 @@ Module: Collect/MYD11
 import os
 import numpy as np
 import pandas as pd
-import gdal
+from osgeo import gdal
 import urllib
 from bs4 import BeautifulSoup
 from joblib import Parallel, delayed
