@@ -6,8 +6,7 @@ Created on Fri Dec 16 19:04:22 2016
 """
 import pandas as pd
 import glob
-import gdal
-import osr
+from osgeo import gdal, ogr, osr
 import os
 import sys
 import numpy as np
@@ -15,6 +14,7 @@ import subprocess
 from pyproj import Proj, transform
 import scipy.interpolate
 import fiona
+import requests
 import pycurl
 import shapefile
 
@@ -1101,8 +1101,6 @@ def Vector_to_Raster(shapefile_name, filename, Attribute_name):
     reference_raster_data_name -- destination file as example file
 
     """
-    from osgeo import gdal, ogr
-
     try:
         if filename.split('.')[-1] == 'tif':
             dest_ex = gdal.Open(r"%s" %filename)
@@ -1230,12 +1228,23 @@ def getWKT_PRJ(epsg_code):
     
     else:
         if sys.version_info[0] == 3:
-            import urllib
-            wkt = urllib.request.urlopen("http://spatialreference.org/ref/epsg/{0}/prettywkt/".format(epsg_code))
-            input_str = wkt.read().decode('utf-8')
-            #replace_slash = input_str.replace("\\", " ") 
-            remove_space = input_str.replace(" ","")     
-            output = remove_space.replace("\n", "")    
+            wkt = requests.get(
+                "http://spatialreference.org/ref/epsg/{0}/prettywkt/"
+                .format(epsg_code))
+            
+            if wkt.status_code == 502:
+                print("http://spatialreference.org is offline, osr is used to get"\
+                         "projection")
+
+                srs = osr.SpatialReference()
+                srs.ImportFromEPSG(int(epsg_code))
+                output = srs.ExportToWkt()
+                
+            else:
+                input_str = wkt.content.decode('utf-8')
+                remove_space = input_str.replace(" ","")     
+                output = remove_space.replace("\n", "")                    
+                        
     
         if sys.version_info[0] == 2:
             import urllib2
